// ******************************************************************
// Iframe support functions
// ******************************************************************

// ****************************************************************** 
// Name   :	Get_Iframe_Element()
// Purpose: Returns the element represented by the given Id.
// Inputs : elementId
// Outputs: NONE 
function Get_Iframe_Element( elementId )
{
   var anElement = 0;
   var myIframe = document.getElementById('inlineFrameId');
   if (myIframe)
   {
      if (isIE)
	  {	 // IE DOM syntax
		 anElement = myIframe.Document.getElementById( elementId );
	  }
	  else
	  {  // W3C DOM syntax
	     anElement = myIframe.contentDocument.getElementById( elementId );
	  }

	  if ( isDebugMode && ( anElement == null ))
	  {
		 alert(elementId + " Is Not Part of Current iFrame View!");
	  }
   }                                 
   return (	anElement );
}

// ****************************************************************** 
// Name   :	Hide_Iframe_Element()
// Purpose: Hide the element represented by the given Id.
// Inputs : elementId
// Outputs: NONE 
function Hide_Iframe_Element( elementId )
{
   var anElement = Get_Iframe_Element( elementId ) ;
   if ( anElement )
      anElement.style.visibility = 'hidden';
}

// ****************************************************************** 
// Name   :	Show_Iframe_Element()
// Purpose: Makes the element represented by the given Id visible.
// Inputs : elementId
// Outputs: NONE 
function Show_Iframe_Element( elementId )
{
   var anElement = Get_Iframe_Element( elementId ) ;
   if ( anElement )
      anElement.style.visibility = 'visible';
}

// ****************************************************************** 
// Name   :	Focus_Iframe()
// Purpose: Gives the focus to the iFrame.
// Inputs : NONE
// Outputs: NONE 
function Focus_Iframe( )
{
   var myIframe = document.getElementById('inlineFrameId');
   if (myIframe)
      myIframe.focus();
}

// ****************************************************************** 
// Name   :	Update_Alarm_Leds_Status()
// Purpose: Makes the elements represented by the given Ids visible or hidden.
// Inputs : elementId
// Outputs: NONE 
function Update_Alarm_Leds_Status(isLedOn, darkLed, colorLed)
{
   if (isLedOn)
   {
      Hide_Iframe_Element( darkLed );
      Show_Iframe_Element( colorLed );
   }
   else
   {
      Show_Iframe_Element( darkLed );
      Hide_Iframe_Element( colorLed );
   }
}

// ****************************************************************** 
// Name   :	Update_Iframe_Element_Top_Property()
// Purpose: Changes the top property of the element represented by the given Id 
// Inputs : elementId
// Outputs: NONE 
function Update_Iframe_Element_Top_Property( elementId, value )
{
   var anElement = Get_Iframe_Element( elementId ) ;
   if ( anElement )	 
      anElement.style.top = value;
}

// ****************************************************************** 
// Name   :	Update_Iframe_Element_Height_Property()
// Purpose: Changes the height property of the element represented by the given Id 
// Inputs : elementId
// Outputs: NONE 
function Update_Iframe_Element_Height_Property( elementId, value )
{
   var anElement = Get_Iframe_Element( elementId ) ;
   if ( anElement )	 
      anElement.style.height = value;
}

// ****************************************************************** 
// Name   :	Update_Iframe_Element_Select_Content()
// Purpose: Parses a input string and extracts select element content 
// Inputs : elementId, aSelectContent
// Outputs: NONE 
function Update_Iframe_Element_Select_Content( elementId, aSelectContent)
{
   var anElement = Get_Iframe_Element( elementId ) ;
   if ( anElement )
      Update_Element_Select_Content( anElement, aSelectContent)
}

// ****************************************************************** 
// Name   :	UpdateIframe()
// Purpose: Replace the current iFrame with the one pointed to by the
//          button just clicked upon.
// Inputs : aLink
//          frameId
// Outputs: NONE 
function UpdateIframe(aLink, frameId, navName)
{
   var newIframe;

   clickedEventHandler(navName);

   // Explicitely remove the iFrame node
   var anElement = document.getElementById(frameId);
   if (anElement)
      anElement.parentNode.removeChild(anElement);

   newIframe = document.createElement("iframe");
   newIframe.setAttribute("id", frameId);
   newIframe.setAttribute("src", aLink);
   newIframe.setAttribute("frameborder", "0");
   newIframe.setAttribute("vspace", "0");
   newIframe.setAttribute("hspace", "0");
   newIframe.setAttribute("marginwidth", "0");
   newIframe.setAttribute("marginheight", "0");

   if ( aLink == "monevent.htm" || aLink == "sysfeatr.htm" )	 
      newIframe.setAttribute("scrolling", "yes");
   else
      newIframe.setAttribute("scrolling", "no");

   // Insert the iFrame into the document to give it context
   document.body.appendChild(newIframe);
   
   iFrameLink = aLink;
}

// ****************************************************************** 
// Name   :	AdjustIframeSize()
// Purpose: To size the iframe element correctly. We must wait for the iframe 
//          content to load, and then find out the content height.
// Inputs : NONE
// Outputs: NONE 
function AdjustIframeSize()
{
   var myIframe = document.getElementById('inlineFrameId');
   if (myIframe)
   {
      if (isIE)
	  {	 // IE DOM syntax
		 if (myIframe.Document && myIframe.Document.body.scrollHeight)
		 {
		    myIframe.height = myIframe.Document.body.scrollHeight;
		 }
	  }
	  else
	  {  // W3C DOM syntax
		 if (myIframe.contentDocument && myIframe.contentDocument.body.offsetHeight)
		 {
		    myIframe.height = myIframe.contentDocument.body.offsetHeight;
		 }
	  }

	  // Bind onload events to iframe
//	  if (myIframe.addEventListner)
//	  {
//		  myIframe.addEventListner("load", ResizeIframe, false);
//	  }
//	  else
//	  {
//		  myIframe.attachEvent("onload", ResizeIframe);
//	  }
   }
}

// ****************************************************************** 
// Name   :	ResizeIframe()
// Purpose: 
// Inputs : anEvent
// Outputs: NONE 
function ResizeIframe(anEvent)
{
   anEvent = (anEvent) ? anEvent : ((window.event) ? event : null);
   var aTarget = (anEvent.target) ? anEvent.target : anEvent.srcElement;
   // Take care of W3C event processing from iframe's root document
   if (aTarget.nodeType == 9)
   {
	  if (anEvent.currentTarget && anEvent.currentTarget.tagName.toLowerCase() == "iframe")
	  {
		 aTarget = anEvent.currentTarget;
	  }
   }
   if (aTarget)
   {
	  AdjustIframeSize(aTarget.id);
   }
}

