// *****************************************************************************
// These functions are text validation functions.All of them are to be invoked 
// by both the onchange() event handler of the text box and a batch validation 
// function triggered by the onSubmit event handler of the enclosing form.


// *****************************************************************************
// Name   : IsNotEmpty()
// Purpose: Validates that the field value string has one or more characters in it.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = String is empty, true otherwise
function IsNotEmpty(anElement)
{
   var str = anElement.value;
   if (str == null || str.length == 0)
   {
      alert("Please fill in the required field.");
	  return(false);
   }
   else
   {
	  return(true);
   }
}

// *****************************************************************************
// Name   : IsNumber()
// Purpose: Validates that the entry is a positive or negative number.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = Not a number, true otherwise
function IsNumber(anElement)
{
   var str = anElement.value;
   var oneDecimal = false;
   var oneChar = 0;

   // Make sure value hasn't cast to a number data type
   str = str.toString();
   for (var i=0; i < str.length; i++)
   {
      oneChar = str.charAt(i).charCodeAt(0);
	  // OK for minus or plus signs as first character
	  if (oneChar == 45 || oneChar == 43)
	  {
	     if (i == 0)
		 {
		    continue;
		 }
		 else
		 {
			alert("Only the first character may be a sign character.");
			return(false);
		 }
	  }
	
	  // OK for one decimal point
	  if (oneChar == 46)
	  {
	     if (!oneDecimal)
		 {
			oneDecimal = true;
		    continue;
		 }
		 else
		 {
			alert("Only one decimal is allowed in a number.");
			return(false);
		 }
	  }
	  	 
	  // Characters outside of 0 through are not OK
	  if (oneChar < 48 || oneChar > 57)
	  {
	     alert("Enter only numbers into the field.");
		 return(false);
	  }
   }
   return(true);
}

// *****************************************************************************
// Name   : IsPhone()
// Purpose: Validates that the entry is a phone number.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = Not a number, true otherwise
function IsPhone(anElement)
{
   var str = anElement.value;
   var oneChar = 0;

   // Make sure value hasn't cast to a number data type
   str = str.toString();
   for (var i=0; i < str.length; i++)
   {
      oneChar = str.charAt(i).charCodeAt(0);
	  	 
	  // Characters outside of 0 through 9 (except +) are not OK
	  if ((oneChar != 43) && (oneChar < 48 || oneChar > 57))
	  {
	     alert("Enter only numbers and '+' into the field.");
		 return(false);
	  }
   }
   return(true);
}

// *****************************************************************************
// Name   : IsPositiveInteger()
// Purpose: Validates that the entry is a positive number.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = Not a number, true otherwise
function IsPositiveInteger(anElement)
{
   var str = anElement.value;
   var oneChar = 0;

   // Make sure value hasn't cast to a number data type
   str = str.toString();
   for (var i=0; i < str.length; i++)
   {
      oneChar = str.charAt(i).charCodeAt(0);
	  // OK for plus sign as first character
	  if (oneChar == 43)
	  {
	     if (i == 0)
		 {
		    continue;
		 }
		 else
		 {
			alert("Only the first character may be a plus sign character.");
			return(false);
		 }
	  }

	  // Characters outside of 0 through are not OK
	  if (oneChar < 48 || oneChar > 57)
	  {
	     alert("Enter only positive integers into the field.");
		 return(false);
	  }
   }
   return(true);
}

// *****************************************************************************
// Name   : IsNumeral()
// Purpose: Allow only numerals 0 through 9 (no decimals or minus signs)
//          Ascii values below 32 are allowed to pass through. These are non-
//          alphanumeric characters, including the Backspace(8), Tab(9), and Return(13) 
//          keys. Users need to be able to edit their entries.
// Inputs : anEvent
// Outputs: false = Not a number, true otherwise
function IsNumeral( anEvent )
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : ((anEvent.keyCode) ? anEvent.keyCode : 
                  ((anEvent.which) ? anEvent.which : 0));
   if (charCode > 31 && (charCode < 48 || charCode > 57))
   {
	  alert("Enter numerals only in this field.");
	  return(false);
   }
   return(true);
}

// *****************************************************************************
// Name   : IsLetter()
// Purpose: Allow letters of both cases to pass to the text box
//          Ascii values below 32 are allowed to pass through. These are non-
//          alphanumeric characters, including the Backspace(8), Tab(9), and Return(13) 
//          keys. Users need to be able to edit their entries.
// Inputs : anEvent
// Outputs: false = Not a letter, true otherwise
function IsLetter( anEvent )
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : ((anEvent.keyCode) ? anEvent.keyCode : 
                  ((anEvent.which) ? anEvent.which : 0));
   if (charCode > 31 && (charCode < 65 || charCode > 90) && (charCode < 97 || charCode > 122 ))
   {
	  alert("Enter letters only in this field.");
	  return(false);
   }
   return(true);
}

// *****************************************************************************
// Name   : IsYesNo()
// Purpose: Allow only Y or N letters of both cases
//          Ascii values below 32 are allowed to pass through. These are non-
//          alphanumeric characters, including the Backspace(8), Tab(9), and Return(13) 
//          keys. Users need to be able to edit their entries.
// Inputs : anEvent
// Outputs: false = Not Y or N, true otherwise
function IsYesNo( anEvent )
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : ((anEvent.keyCode) ? anEvent.keyCode : 
                  ((anEvent.which) ? anEvent.which : 0));
   if (charCode > 31 && charCode != 78 && charCode != 89 && charCode != 110 && charCode != 121 )
   {
	  alert("Enter \"Y\" or \"N\" only.");
	  return(false);
   }
   return(true);
}

// *****************************************************************************
// Name   : IsLength16()
// Purpose: Validates that the entry is 16 characters long.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = Does not have a length of 16 charcaters, true correct length
function IsLength16(anElement)
{
   var str = anElement.value;
   if (str.length != 16)
   {
      alert("Entry does not contain the required 16 characters.");
	  return(false);
   }
   else
   {
	  return(true);
   }
}

// *****************************************************************************
// Name   : IsValidIpAddress()
// Purpose: Validates that the entry is a valid IP address.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = Is not a valid IP address, true correct format
function IsValidIpAddress(anElement)
{
   var str = anElement.value;

   if (str.indexOf(".") > 0)
   {
      var addr1 = str.substring(0, str.indexOf("."));
      var str1 = str.substring(str.indexOf(".") + 1, str.length);
      for (var i=0; i < addr1.length; i++)
      {
         oneChar = addr1.charAt(i).charCodeAt(0);
         if (oneChar < 48 || oneChar > 57)        // Only numbers 0..9 are valid
         {
            alert("INVALID IP ADDRESS FORMAT.");
            return(false);
         }
      }

      if (str1.indexOf(".") > 0)
      {
         var addr2 = str1.substring(0, str1.indexOf("."));
         var str2 = str1.substring(str1.indexOf(".") + 1, str1.length);
         for (var i=0; i < addr2.length; i++)
         {
            oneChar = addr2.charAt(i).charCodeAt(0);
            if (oneChar < 48 || oneChar > 57)        // Only numbers 0..9 are valid
            {
               alert("INVALID IP ADDRESS FORMAT.");
               return(false);
            }
         }

         if (str2.indexOf(".") > 0)
         {
            var addr3 = str2.substring(0, str2.indexOf("."));
            var addr4 = str2.substring(str2.indexOf(".") + 1, str2.length);
            for (var i=0; i < addr3.length; i++)
            {
               oneChar = addr3.charAt(i).charCodeAt(0);
               if (oneChar < 48 || oneChar > 57)        // Only numbers 0..9 are valid
               {
                  alert("INVALID IP ADDRESS FORMAT.");
                  return(false);
               }
            }
            for (var i=0; i < addr4.length; i++)
            {
               oneChar = addr4.charAt(i).charCodeAt(0);
               if (oneChar < 48 || oneChar > 57)        // Only numbers 0..9 are valid
               {
                  alert("INVALID IP ADDRESS FORMAT.");
                  return(false);
               }
            }
         }
         else
         {
            alert("INVALID IP ADDRESS FORMAT.");
            return(false);
         }
      }  
      else
      {
         alert("INVALID IP ADDRESS FORMAT.");
         return(false);
      }
   }
   else
   {
      alert("INVALID IP ADDRESS FORMAT.");
      return(false);
   }

   return(true);                               // Valid IP address
}

// *****************************************************************************
// Name   : IsValidEthernetAddress()
// Purpose: Validates that the entry is a valid ethernet address.
// Inputs : anElement = Reference to the form control invoking the event handler
// Outputs: false = Is not a valid ethernet address, true correct format
function IsValidEthernetAddress(anElement)
{
   var str = anElement.value;
   if (IsNotEmpty(anElement))
   {
      if (str.length > 12)
      {
         alert("Entry contains more than the 12 hex digits allowed.");
  	      return(false);
      }
   }

   return(true);                               // Valid ethernet address
}

// *****************************************************************************
// Name   : FormatCommas()
// Purpose: Format's a number by inserting commas. This function assumes only the
//          integer portion of a number is passed to it. It works best with a script
//          that divides a number into its integer and fractional components during
//          the formatting process. It inserts commas for displaying large numbers 
//          by using regular expressions.
// Inputs : numString = Integer portion of a number
// Outputs: 
function FormatCommas(numString)
{
   var re = /(-?\d+)(\d{3})/;
   while (re.test(numString))
   {
	  numString = numString.replace(re, "$1,$2");
   }
   return(numString);
}

// *****************************************************************************
// Name   : StripCommas()
// Purpose: This function strips commas from large numbers
// Inputs : numString
// Outputs: 
function StripCommas(numString)
{
   var re = /,/g;
   return (numString.replace(re,""));
}

// *****************************************************************************
// Name   : StripDots()
// Purpose: This function strips dots from a decimal number
// Inputs : numString
// Outputs: 
function StripDots(numString)
{
   var re = /./g;
   return (numString.replace(re,""));
}

// *****************************************************************************
// Name   : FormatNumber()
// Purpose: Format's a number with a fixed number of digits to the right of the
//          decimal.
// Inputs : aNumber
//			decPlaces
// Outputs: 
function FormatNumber(aNumber, decPlaces)
{
   var newNumber;
   // Convert in case it arrives as a string value
   newNumber = parseFloat(aNumber);
   // Make sure it passes conversion
   if (!isNaN(newNumber))
   {
	  // Multiply value by 10 to the decPlaces power, round the result to the nearest
	  // integer, then convert the result to a tring
	  var str = "" + Math.round(eval(newNumber) * Math.pow(10, decPlaces));
	  // Exponent means value is too big or too small for this routine
	  if (str.indexOf("e") != -1)
	  {
		 return("Out of Range");
	  }
	  // If needed for small values, pad zeros to the left of the number
	  while (str.length <= decPlaces)
	  {
		 str = "0" + str;
	  }

	  // Calculate decimal point position
	  var decPoint = str.length - decPlaces;
	  // Assemble final result
//	  newNumber = formatCommas(str.substring(0, decPoint)) + "." + str.substring(decPoint, str.length);
	  newNumber = str.substring(0, decPoint) + "." + str.substring(decPoint, str.length);
	  return(newNumber);
   }
   else
   {
	  return("NaN");
   }
}

// *****************************************************************************
// Name   : AutoFocus()
// Purpose: This function advances the focus to a form field ID element after a 
//          set number of characters.
// Inputs : aField
//          aLimit
//          nextElementId
//          anEvent 
// Outputs: 
function AutoFocus(aField, aLimit, nextElementId, anEvent)
{
   anEvent = (anEvent) ? anEvent : event;
   var charCode = (anEvent.charCode) ? anEvent.charCode : ((anEvent.keyCode) ? anEvent.keyCode : 
                  ((anEvent.which) ? anEvent.which : 0));
   if (charCode > 31 && aField.value.length == aLimit)
   {
      var nextElement = Get_Iframe_Element( nextElementId ) ;
      if ( nextElement )
      {
         nextElement.focus();
         nextElement.select();
      }
   }
}

// ***************************************************************
// Name   : decimalToHex()
// Purpose: This function converts between a decimal number (between 0 and 255)
//          to a hexadecimal string equivalent. Because JavaScript automatically
//          converts hex numbers to their decimal equivalents for arithmetic
//          operations, this hexidecimal conversion is needed only for display
//          of a hexidecimal result.
// Inputs : aDecimal
// Outputs: aResult = Hex string
function decimalToHex( aDecimal )
{
   aDecimal = parseInt(aDecimal, 10);
   if (!isNaN(aDecimal))
   {
      hexChars = "0123456789ABCDEF";
      if (aDecimal > 255)
         return("Out of Range");
      var i = aDecimal % 16;
      var j = (aDecimal -i) / 16;
      aResult = "0x";
      aResult += hexChars.charAt(j) + hexChars.charAt(i);
      return(aResult);
   }
   return(NaN);
}